#include "lib_acl.h"

#ifdef WIN32
#define snprintf _snprintf
#endif

#define TOTAL_CHAR		2359
#define TOTAL_CHAR_BUF	4724

static char __szJJ[TOTAL_CHAR_BUF]=
"场础贰尽馈谩拧伞獭选摇铡帧荨纭椤辍怼铩颉鳌并尝储发饥舰劲垄泞挞癣尧闸症注撷恽纰辎铫颌鳍担罚迹剑荆溃拢"
"牵龋遥樱郑郏荩撸澹妫纾辏欤铮穑颍觯鳎长钉护饯沥陇扦胜韦绚窑婴预栅证驻荬猡浃绀椁辘铯颏鳏饱偿触单顶讥渐"
"茎骏隶楼钮钎丧圣违啸谣鹰讠荪撺幞悭浈绁辚铳颔籁鳐宝拨肠处郸沪鸡溅娄纽铅师应驭讦郐荭擀绂铴颚酽靓鳓钵厂"
"掸锭阀抚骇户涧搂脓颧骚帅抬围学缨鸳讧郄荮绉戋毵铵颛酾鳔皑报胆辅龚绩鲸篓猫浓迁权扫狮台莹渊专亘讪猕绋瑷"
"戗悫铷瘿颞雳鳕畅订珐哗缉扩俩农签药萤诈砖讴郓姗绌飑铹颟鳗蔼丢华惊开联锚湿为营转讵郦莳绐氇飒愍铼颡鳘鲍"
"传东韩极将阔莲芦谦诗双潍蝎勋荧斋讷莴岖惬浍娅绔飓铽瘾颢霁鳙铂惮宫浆连卢涩尸态维蝇赚诂娆绗璎飕铿颥鳜碍"
"画辑经凯镰颅铆骗谁铜苇协侪诃蕲岘绛榄飙锃颦鳝爱钞诞巩划庐飘钱袭挟赢债桩诋岙娈绠飚锂癞鳟疮弹动矾蒋蜡怜"
"炉钳摊携询爷辕织庄侬诏莜浏绡戬懑锆鸠舣鳢栋钒话桨腊涟掳劝税贪伟习寻园职装诎莅岚浒灏绨戆锇鸢霭当贡奖颈"
"帘卤谋疟潜杀时瘫伪驯颖员毡妆俦诒弑浔绫瓯毂锉鸨虮辈挡讲静敛虏刹滩胁圆俨诓莶绮氩锊鸩癫虿鞑闯党冻烦赋钩"
"怀莱脸鲁贸浅顺坛统纬铣谐页壮俪诔愠绯锍鸪癯龀鞒贝创荡复酱来链么谴却纱蚀写哟执状诖薮叽岽愦娲绱榇齑泶畲"
"锎鸫龃钡驳车档沟坏镜赖恋诺频堑鹊实说训业拥缘盏诘莸涞娴绲榈氲斓淼锏鸬舻龅鞯范苟欢级径蓝炼亩贫识硕讯叶"
"佣远斩锥俣诙喽愣涠缍瓒矶锒鸲龆狈卜捣斗贩环挤痉练欧确谭头戏逊辗诜喾绶榉锓鸱龇备锤几栏粮赂鸥筛烁谈细痈"
"愿崭赘诟吒甯绺韪砀锔鸶龈肮惫补彻饭构还拦凉霉殴枪晒喂压坠诠骞绻韫牍锕鸸蚬龉鞴岛负购汉缓胶竞篮呛秃虾泻"
"缀睾诤莺藓绾韬砗锖鸷蚝鹾龊祷够换蓟净阑禄没呕苹驶谢鸦踊栈谆诨刍莼藁峄缁锘鸹趸龌导讣兰录图鸭约准诩奂芗"
"呒饧缂昙罴锛鸺窦黾唤浇澜两陆沤墙谓辖医咏战纸诮劢呓峤饨缃锝鸾鼋鹘尘妇痪骄谰辆镁凭蔷删叹跃志诰饩缇炀锞"
"鹁鼍翱纯犊缚娇揽驴强丝涂峡锌铱涌钥挚诳芸呖嗫峥饪婵缈杩炜砜羁锟鹂罂袄独焕纠览吕评抢汤卫侠岳绽掷诶崂饫"
"憷缋枥槔炖锢鹄窭绷沉盗读涣剂搅懒铝闪狭粤诹蘖崃饬懔媪缌炝锪鹆袅隽奥陈绰铰缆谅侣锹陕温芈诼勐苈呗饴渎缏"
"砺锫鹇访该济矫烂泼让厦颐悦诿呙饷缑砻锩鹈蛎髅衬赌纺侥滥颇饶赡阅帜啬谀吣饽缒槟锬鹉跄撑号脚颗琅屡门呐桥"
"扰团闻吓遗优张着谂馀闩渑缗枧钆锱鹋雠髋财称灯镀钙蛊黄计疗缕闷钠绕势纹衅哑云谄奁馄闫缙槠钇锲鹌笃髌辞盖"
"记厩壳虑们乔饲颓锨亚仪忧郧涨浊厍偾谇咔馇闱迩缜枨烨钋锴鹎羟銮饺侨热稳讶匀兹谌苋嗳馊闳嫒缛枞钊锶鹑笕跞"
"飞干缴旧辽纳缮蜕陨厣谏苌嵘馍闵渖迳嫔缟枭樯肷钌锷鹕裆蛏錾笔词际绞墒适耸问鲜邮帐质资谑凼苁馐闶缡晔胧钍"
"锸鹗魇邓杆顾滤扑伤怂纤兴阉铀运账厮谒馑闼渌缢胨焖钏锼鹚魉诽继捞绿锰盘铺翘颂烫咸烟犹蕴靥偬谔咛馓闾缣硖"
"钐锾鹛蛱籼惩赐锻纪劳镣峦韧赏释瓮贤彝酝胀滞赝偻谕馔阃嫱缤橥晖胪硗钔锿鹜裢蛲参轿课挛梦饰涛挝衔盐游晕傥"
"谖辔嵛馕阄逦缥栉煳钗镂鹞跷毕蚕诚聪断废赶较孪窍认讼蜗严蚁韵傧谙巯尴阆缦钕锵鹣裣蛳粝跸鱿飨毙残葱敌缎剐"
"夹滦眯诵绦涡闲匦傩谛苄咝嵝庑阈缧栊钚镄鹦裥粜鲂餍惭囱费秆谎垦难脱窝匮谘垩苎扪阊缪煅钛镅鹧跹鲅币惨骋兑"
"挂阂恳乱纫鸵岩谝抟阋缫钜镆鹨跻鲆坝灿从涤队赣挥挠庞朴视擞杂钟赜谟萦嘤阌溆缬栌暧碛钣镉鹩蛴鲇苍丛对冈辉"
"荚驹涝猎脑窃试驮卧显赵谠菰咴阍缭钤镌鹪鲈罢闭舱痴凑刚颊秸抡谜恼钦烧苏驼险颜艺诱终渍谡哒嵴阏缯钫镎鹫稣"
"仓吨钢贾乐轮弥闹讨椭现阎灾种谥阒嬷缰橹胫熘钪镏鹬笾糁鲋沧纷鹤阶伦抛谱亲献凶肿谧茏阕缱碜钭镒鹱鲎坟关贺"
"钾镭仑呜县载谪挢哓阖缲钬镓鹭鲐迟顿纲毁举抠临沦觅馁荣寿钨踪刭谫哔噘赓阗滟缳栀钯镔鹳筚踬鲑摆蹿岗节邻纶"
"内腾乌馅汹亿于众谮阙缵橼贲脍钰镖褛鲒驰钝观价鳞论污羡综刿谯圹蒇巅阚贳钲镗鲔败耻窜奋杰萝栖绍誊诬宪攒总"
"剀谲苘哕丬滠贶钴镘疖褴踯鲕齿递馆驾据垒凛幂洼暂蛰纵佥谳彷栎檩贻钶镙疠筝鲚厕缔皋赁罗寝绒赊兽无艳赞辙邹"
"谵坜蒉廪滢贽磙钷镛鲛鬓边颠愤惯贿歼逻诉芜线舆赃诌谶柽赀钸镞疬襁鲞编侧粪秽监洁类锣绵凄枢肃锑袜脏锗坂茑"
"哙噜驵赅钹镟鲟贬册夺丰贯横会坚结泪箩轻厢厌轴籴卺驷玑赆脶钺镝鲠麽测烩锯库骡拟赔氢题吴镶锈砚这垅掴哜徕"
"驸玮桠殁赈焘钼镡疴鲡层炽点枫广汇笺裤倾摄鱼茔忏沣溷驺桡赉钽镢鲢颁变镐轰讳间夸龄输虽弯忆凿黉垆茕蒌怃滗"
"驿殇赇钿镤皲鲣冲冲诲惧铃缅腻慑体湾绣彦义皱驽珏桢赍铄镥疱蝈箦鲥虫垫锋规绘骆随渔枣冁哝怄骀殒赕铈镦箧蹑"
"鲦辩电风荤剧络喷绥顽乡昼诅骁珑桤殓赙铉镧蹒鲧辫宠疯硅鸿艰凌妈设谚诣骤掼噼徼骅觇龛铊镨鲨堕搁归鹃块篱灵"
"书虚验议娱组荛唛忾骈殚觊铋镩痖蹰鲩标龟缄狸玛脐顷赎岁详嘘谊贞钻陉荜揸怅骊觋铌镪箨絷鲫畴冯鸽闺浑茧诫侩"
"离岭码齐请屉坞须译与针垭蓦唠嚯怆潆骐珉桦殡觌铍镫鲭办踌鹅缝轨红检届领蚂撵庆响鸯异屿侦凫揿潇骒觎铎镬痨"
"耢箪鲮绊错淀讽宽马庙捻琼软雾许猪陧沩漤骓桧轫觏铐镯鲰鳖额诡碱绢骂穷项杨灶诸垲犷骖轭觐眍铑镱蝾鲱帮诧筹"
"达讹凤伙硷里骑孙扬绎语诊诛唢犸骘顼栾轱觑腼铒镲痫耧箫麸躏鲲别拣鲤吗灭酿绅损叙责兖垧囵屦骛桊轲腽铕镳麴"
"鲳瘪绸恶柜获捡礼鸟岂锐笋务疡荫择伛垴荞蓠泷骜桉轳铖锺篑鲴凋简买闰万则镇烛衮泸潋弪骝轵祢铗躜鲵黩绑搀丑"
"阁贵后俭矿馏麦润审误泽阵摅狍潴骟轶铙鲶濒掺肤刽紧卖聂鹏启婶属萧阳贼亵骠玺轸铘鲷滨蝉铬辊货减锦觉旷刘迈"
"悯术缩条阴吁挣瞩脔埘啧骢珲轷祯铛趱鲺黪宾馋钓饿个滚祸荐仅决况丽脉闽啮肾琐睁嘱伥埚荟蓥狯骣琏轹眦铞鲻镑"
"摈谗橱调击槛谨诀亏厉瞒镊趋洒树绪痒伧禀邝埙蓣骥轺膑铟瘅聍蝼鲼缠厨带辐给锅壶鉴进绝励馒镍气区萨渗锁网续"
"养银狰帏狲怿泺骧轼禅铠鲽谤铲儿践岿砾蛮鸣声贴嚣轩样御赠争伫邬荠啭纟棂轾睐铢稆瘗聩鳄产锄国机贱晋窥历龙"
"满铭弃鳃竖铁销扎恸纡辁睑铤鳅鼹阐雏贷尔见钧聋柠躯饮埯恹纣辂铥鳆颤迭饵键军咙狞赛厅悬狱贮蔹撄帱恻妩纥椟"
"辄睃铧瘘顸觞鳇饼谍过积烬笼谬讫驱数听锡札铸荦帻猃恺妪纨椠辇铨颀螨簖鳊剥叠宁绳烃牺晓瑶隐誉轧筑邺埝荥蔺"
"帼泾濑纩辋铪颃鳋齄\0\0";

static char __szJF[TOTAL_CHAR_BUF]=
"場礎貳盡饋謾擰傘獺選搖鍘幀蕁紜欏輟懟鎩頡鰲並嘗儲發饑艦勁壟濘撻癬堯閘癥註擷惲紕輜銚頜鰭擔罰跡劍荊潰攏"
"牽齲遙櫻鄭郟藎擼淡媯紓輳歟錚穡潁觶鰨長釘護餞瀝隴扡勝韋絢窯嬰預柵證駐蕒玀浹紺槨轆銫頦鰥飽償觸單頂譏漸"
"莖駿隸樓鈕釬喪聖違嘯謠鷹訁蓀攛襆慳湞紲轔銃頷籟鰩寶撥腸處鄲滬雞濺婁紐鉛師應馭訐鄶葒搟紱鐋顎釅靚鰳缽廠"
"撣錠閥撫駭戶澗摟膿顴騷帥擡圍學纓鴛訌郤葤縐戔毿銨顓釃鰾皚報膽輔龔績鯨簍貓濃遷權掃獅臺瑩淵專亙訕獼紼璦"
"戧愨銣癭顳靂鱈暢訂琺嘩緝擴倆農簽藥螢詐磚謳鄆姍絀颮鐒顢鰻藹丟華驚開聯錨濕為營轉詎酈蒔紿氌颯湣錸顙鰵鮑"
"傳東韓極將闊蓮蘆謙詩雙濰蠍勛熒齋訥萵嶇愜澮婭絝颶鋱癮顥霽鱅鉑憚宮漿連盧澀屍態維蠅賺詁嬈絎瓔颼鏗顬鱖礙"
"畫輯經凱鐮顱鉚騙誰銅葦協儕訶蘄峴絳欖飆鋥顰鱔愛鈔誕鞏劃廬飄錢襲挾贏債樁詆嶴孌綆飈鋰癩鱒瘡彈動礬蔣蠟憐"
"爐鉗攤攜詢爺轅織莊儂詔蓧瀏綃戩懣鋯鳩艤鱧棟釩話槳臘漣擄勸稅貪偉習尋園職裝詘蒞嵐滸灝綈戇鋨鳶靄當貢獎頸"
"簾鹵謀瘧潛殺時癱偽馴穎員氈妝儔詒弒潯綾甌轂銼鴇蟣輩擋講靜斂虜剎灘脅圓儼誆薟綺氬鋝鴆癲蠆韃闖黨凍煩賦鉤"
"懷萊臉魯貿淺順壇統緯銑諧頁壯儷誄慍緋鋶鴣臒齔鞽貝創蕩復醬來鏈麽譴卻紗蝕寫喲執狀詿藪嘰崠憒媧緔櫬齏澩畬"
"鐦鶇齟鋇駁車檔溝壞鏡賴戀諾頻塹鵲實說訓業擁緣盞詰蕕淶嫻緄櫚氳斕渺鐧鸕艫齙韉範茍歡級徑藍煉畝貧識碩訊葉"
"傭遠斬錐俁詼嘍楞潿綞瓚磯鋃鴝齠狽蔔搗鬥販環擠痙練歐確譚頭戲遜輾詵嚳綬櫸鋟鴟齜備錘幾欄糧賂鷗篩爍談細癰"
"願嶄贅詬咤寧綹韙碭鋦鷥齦骯憊補徹飯構還攔涼黴毆槍曬餵壓墜詮騫綣韞牘錒鴯蜆齬韝島負購漢緩膠競籃嗆禿蝦瀉"
"綴睪諍鶯蘚綰韜硨錆鷙蠔鹺齪禱夠換薊凈闌祿沒嘔蘋駛謝鴉踴棧諄諢芻蒓槁嶧緇鍩鴰躉齷導訃蘭錄圖鴨約準詡奐薌"
"嘸餳緙曇羆錛鵂竇黽喚澆瀾兩陸漚墻謂轄醫詠戰紙誚勱囈嶠飩緗鍀鸞黿鶻塵婦瘓驕讕輛鎂憑薔刪嘆躍誌誥餼緹煬錁"
"鵓鼉翺純犢縛嬌攬驢強絲塗峽鋅銥湧鑰摯誑蕓嚦囁崢飪嬋緲榪煒碸羈錕鸝罌襖獨煥糾覽呂評搶湯衛俠嶽綻擲誒嶗飫"
"怵繢櫪橰燉錮鵠窶繃沈盜讀渙劑攪懶鋁閃狹粵諏蘗崍飭懍媼緦熗鍃鵒裊雋奧陳綽鉸纜諒侶鍬陜溫羋諑猛藶唄飴瀆緶"
"礪錇鷴訪該濟矯爛潑讓廈頤悅諉咼餉緱礱錈鵜蠣髏襯賭紡僥濫頗饒贍閱幟嗇諛唚餑縋檳錟鵡蹌撐號腳顆瑯屢門吶橋"
"擾團聞嚇遺優張著諗餘閂澠緡梘釓錙鶓讎髖財稱燈鍍鈣蠱黃計療縷悶鈉繞勢紋釁啞雲諂奩餛閆縉櫧釔鍥鵪篤髕辭蓋"
"記廄殼慮們喬飼頹鍁亞儀憂鄖漲濁厙僨誶哢餷闈邇縝棖燁釙鍇鵯羥鑾餃僑熱穩訝勻茲諶莧噯餿閎嬡縟樅釗鍶鶉筧躒"
"飛幹繳舊遼納繕蛻隕厴諫萇嶸饃閔瀋逕嬪縞梟檣膁釕鍔鶘襠蟶鏨筆詞際絞墑適聳問鮮郵帳質資謔氹蓯饈閌縭曄朧釷"
"鍤鶚魘鄧桿顧濾撲傷慫纖興閹鈾運賬廝謁饉闥淥縊腖燜釧鎪鶿魎誹繼撈綠錳盤鋪翹頌燙鹹煙猶蘊靨傯諤嚀饊閭縑硤"
"釤鍰鶥蛺秈懲賜鍛紀勞鐐巒韌賞釋甕賢彜醞脹滯贗僂諭饌閫嬙繽櫫暉臚磽鍆鎄鶩褳蟯參轎課攣夢飾濤撾銜鹽遊暈儻"
"諼轡崳饢鬮邐縹櫛糊釵鏤鷂蹺畢蠶誠聰斷廢趕較孿竅認訟蝸嚴蟻韻儐諳巰尷閬縵釹鏘鶼襝螄糲蹕魷饗斃殘蔥敵緞剮"
"夾灤瞇誦絳渦閑匭儺諦芐噝嶁廡閾縲櫳鈈鐨鸚襇糶魴饜慚囪費稈謊墾難脫窩匱諮堊苧捫閶繆煆鈦鎇鷓躚鮁幣慘騁兌"
"掛閡懇亂紉鴕巖諞摶鬩繅鉅鏌鷚躋鮃壩燦從滌隊贛揮撓龐樸視擻雜鐘賾謨縈嚶閿漵纈櫨曖磧鈑鎘鷯蠐鮎蒼叢對岡輝"
"莢駒澇獵腦竊試馱臥顯趙讜菇噅閽繚鈐鐫鷦鱸罷閉艙癡湊剛頰稭掄謎惱欽燒蘇駝險顏藝誘終漬謖噠脊閼繒鈁鎿鷲穌"
"倉噸鋼賈樂輪彌鬧討橢現閻災種謚闃嬤韁櫓脛溜鈧鎦鷸籩糝鮒滄紛鶴階倫拋譜親獻兇腫謐蘢闋繾磣鈄鎰鸌鱟墳關賀"
"鉀鐳侖嗚縣載謫撟嘵闔繰鈥鎵鷺鮐遲頓綱毀舉摳臨淪覓餒榮壽鎢蹤剄譾嗶撅賡闐灩繯梔鈀鑌鸛篳躓鮭擺躥崗節鄰綸"
"內騰烏餡洶億於眾譖闕纘櫞賁膾鈺鏢褸鮚馳鈍觀價鱗論汙羨綜劌譙壙蕆巔闞貰鉦鏜鮪敗恥竄奮傑蘿棲紹謄誣憲攢總"
"剴譎檾噦爿灄貺鈷鏝癤襤躑鮞齒遞館駕據壘凜冪窪暫蟄縱僉讞仿櫟檁貽鈳鏍癘箏鱭廁締臯賃羅寢絨賒獸無艷贊轍鄒"
"譫壢蕢廩瀅贄滾鉕鏞鮫鬢邊顛憤慣賄殲邏訴蕪線輿贓謅讖檉貲鈽鏃癧繈鯗編側糞穢監潔類鑼綿淒樞肅銻襪臟鍺阪蔦"
"噲嚕駔賅鈸鏇鱘貶冊奪豐貫橫會堅結淚籮輕廂厭軸糴巹駟璣贐腡鉞鏑鯁麼測燴鋸庫騾擬賠氫題吳鑲銹硯這壟摑嚌徠"
"駙瑋椏歿賑燾鉬鐔屙鱺層熾點楓廣匯箋褲傾攝魚塋懺灃混騶橈賚鉭鐝鰱頒變鎬轟諱間誇齡輸雖彎憶鑿黌壚煢蔞憮潷"
"驛殤賕鈿鏷皸鰹沖衝誨懼鈴緬膩懾體灣繡彥義皺駑玨楨賫鑠鑥皰蟈簀鰣蟲墊鋒規繪駱隨漁棗囅噥慪駘殞賧鈰鐓篋躡"
"鰷辯電風葷劇絡噴綏頑鄉晝詛驍瓏榿殮賻鉉鑭蹣鯀辮寵瘋矽鴻艱淩媽設諺詣驟摜劈僥驊覘龕鉈鐠鯊墮擱歸鵑塊籬靈"
"書虛驗議娛組蕘嘜愾駢殫覬鉍鑹瘂躕鯇標龜緘貍瑪臍頃贖歲詳噓誼貞鉆陘蓽摣悵驪覡鈮鏹籜縶鯽疇馮鴿閨渾繭誡儈"
"離嶺碼齊請屜塢須譯與針埡驀嘮謔愴瀠騏瑉樺殯覿鈹鐙鯖辦躊鵝縫軌紅檢屆領螞攆慶響鴦異嶼偵鳧撳瀟騍覦鐸鑊癆"
"耮簞鯪絆錯澱諷寬馬廟撚瓊軟霧許豬隉溈濫騅檜軔覯銬鐲鯫鱉額詭堿絹罵窮項楊竈諸塏獷驂軛覲瞘銠鐿蠑鯡幫詫籌"
"達訛鳳夥鹼裏騎孫揚繹語診誅嗩獁騭頊欒軲覷靦鉺鑔癇耬簫麩躪鯤別揀鯉嗎滅釀紳損敘責兗坰圇屨騖棬軻膃銪鑣麯"
"鯧癟綢惡櫃獲撿禮鳥豈銳筍務瘍蔭擇傴堖蕎蘺瀧驁案轤鋮鍾簣鯝雕簡買閏萬則鎮燭袞瀘瀲弳騮軹禰鋏躦鯢黷綁攙醜"
"閣貴後儉礦餾麥潤審誤澤陣攄麅瀦騸軼鐃鯰瀕摻膚劊緊賣聶鵬啟嬸屬蕭陽賊褻驃璽軫鋣鯛濱蟬鉻輥貨減錦覺曠劉邁"
"憫術縮條陰籲掙矚臠塒嘖驄琿軤禎鐺趲鯴黲賓饞釣餓個滾禍薦僅決況麗脈閩嚙腎瑣睜囑倀堝薈鎣獪驏璉轢眥銱鯔鎊"
"擯讒櫥調擊檻謹訣虧厲瞞鑷趨灑樹緒癢傖稟鄺塤蕷驥軺臏銦癉聹螻鱝纏廚帶輻給鍋壺鑒進絕勵饅鎳氣區薩滲鎖網續"
"養銀猙幃猻懌濼驤軾禪鎧鰈謗鏟兒踐巋礫蠻鳴聲貼囂軒樣禦贈爭佇鄔薺囀糸欞輊睞銖穭瘞聵鱷產鋤國機賤晉窺歷龍"
"滿銘棄鰓豎鐵銷紮慟紆輇瞼鋌鰍鼴闡雛貸爾見鈞聾檸軀飲垵懨紂輅銩鰒顫叠餌鍵軍嚨獰賽廳懸獄貯蘞攖幬惻嫵紇櫝"
"輒脧鏵瘺頇觴鰉餅諜過積燼籠謬訖驅數聽錫劄鑄犖幘獫愷嫗紈槧輦銓頎蟎籪鯿剝疊寧繩烴犧曉瑤隱譽軋築鄴墊滎藺"
"幗涇瀨纊輞鉿頏鰠齇\0\0";

static char __szFJ[TOTAL_CHAR_BUF]=
"叹园污获篮绕聋蔼褛谔辕这钻铵锹阑颃显惊倾圆碱夹痨睐础禀舻华蔺讼贮赢辘钏铥阶预颦饷驿鲴厦态渗叠痫筑绍谛"
"贳赆连郦铊铕顽颅养鳔鸟鹛鼹凛愠机烫猎矫窝绀综绣肃荟亵诔谐证钒铉铯镝镯颁喽图妇娈挤凄瘅洼箧缋腊艰觎诛赀"
"转铐锾镭阗顿颞饵凫麴偻抬桢椭滥漤犷绋缍蓟诀诓贰赃迹跷陨颧骏骤鲅鲱团峄焖兽现穷胪夸贵轸钎锥铁雾鲵鸠鹜丢"
"浒睾窑绿艳荆芗讷谏铋饽骋鲆侣仅潍獭绐亲谲贬赎辙铞锕铿阖际颇馁驴鲲呕娅业泪滨营献琏盗筹绌绸肾蕲志谕讥买"
"赝轿键锵铎阙领饿鳙鹱呙奂钦猕绻芦觊认谘贷锐锶闯骧并啧块惨盏碍终绳脏苏铂锟铛骓骥鲳佥尝茔扦滚磙绘胨脔幞"
"访贶长风鲸鳕莺惭拟横满狭猡尽秸窭组萦蛊裥觏讳岂费赣轱进镗颌鳖垲厨烃灿狈种缙翘卜蔷蕴蝼诳贴销锤锗镘馀鲮"
"鹃麽唛孙极渌渔疠监绊缢茧翱苌莼苹设诶谙贻趸辚钗钷锱镛镱鲰鹆齄凯埘厮扬摈盘笔缒罚卧莳觐谮踌郏锈铮铲关骊"
"凤鹁匦恸换拧决称窥缳蚕诞竖贸跻钍钳锛馄鸣鹤俣汇庙搁槔凌溅卢御糁绶缲骂临莱谌识贺锑锺镜阚颉飑马鲇鸬齐侨"
"岙厂掷沦笋粪维苄许讽谯丰贲跃轴郄钕锉镖随飒驭骒鸢黄斋匮员涂庑惯泺烛瓯瘪硕罢脶诱诸谭赂轵铆铸门饯冯骑鲐"
"鲶咔废扩杆禅绾绉缴蛰蛮袅觑赁踯轺铅锬镂阐险颐骐鲍嵘广胧滤痴矿笃纲缣皋蒌诉诮谚谱贿跞轲锭镁闩霁鲋鳟哗奥"
"学欧痒绗网莅莶赅踬轶闪颏馅驮鬓鹦齑岭撷疖砀箨脑蝈觉诃谖蹰钺铝钱锿鞒鲺鳝鹘鹳齿奁怄渊瓮症礼筛结缀蒋蘖里"
"资轼錾闼驰斗鹈鹣唠夺屿怂涞烩砺窜粮语诺贾轰钯锒镬闫雳飓驯鳜鹅鹂黉龀啸岳廪摆疬眯砾祢窍籁绎肿葱览游钫镅"
"隐闹鳞鸾叽孪擞浅矾祷笼茑藓螨袄诊诚谋贼辔运锌锦镔霭缰骛鲟鹚坞庐虑挥撸没滢癞窦纶荐觌注诫谒跹轹邮闭陇阋"
"鹄区哓奋渎玑砜灶绝绺继观谓较过钭钩钡锚镑鞑头馆鲒鹉埙扰檩冲癣确绮缤罗脚台萨诬轳达开骗鹞龅呒瘿窃筚绽缚"
"缱罴蔹误誊践辂违钲闶隶灵飕悭沤泻烬瑷产瘾码砻笕荫补诰诌锡颊肮鲫鲼侠狰痈绰缜羁装诂诵蹑辁遥钚铤鉴闳阄鲕"
"龇庆渖焘瘫粝绫缟肠与刍裣赈钠闰鳊鲎鸩点厅摅栀痉癫秃稣绵缛芈肷兴茏裆诲谵赊载逊锢镲鞯鸨侥徼别欤积笾籴耧"
"腽举谎宾轾铗错闲龃偾协撵柽颖簖绔旧庄万说蹿递钼铧韦鸦龆枧欢浏眍粜绞耢蚀术诋译赇躜钝钽间韧驳鹌龄删呗岿"
"汉环篱县褴议远丑锋镤闵隽颔飘饧党涟籼绲缬谜猪郓锰锁颈鹏咴箦箩络荠酝钤镪颓飙喂珏绚纩谧躏办钣镉鳢条濒发"
"缁虮卫谁谴赉乡闸频飚馇鲽鹎龈尘宫珐瞒纠续兰袜辄适虽鳇峦忧拢枭档渍吁莴苍荨冲讵课赐钞铼靓韩鲔涣泸无纪给"
"紧茎谑嚯护辅辞钮静鲛鹊黪巅损减绯缝缠荪诈赏轻辫铄双鹧龊刭堑杩岁涨烁犹珲纣绒谡辩铰饩骞鲑鳅鲚霉价岩拦时"
"况沥缡苎蒇虾衬诒谇谤赔农雏鲜鸵龉却垧岘弑荣溆狲约缩蝉赓赶铒锊镳杂馏骘伥则撄潇炉玺篓红缨诏谦贤迟医铬铙"
"腼韪馊骝髅鸥黩嘘岛耻摇桧涡渐潆砖纡羟蛲袭评诽谥誉卖邹酱锓锝钨镥阂鸡魉卤惫捣搀历纥纵荚讲谫贱辆锨蓥靥驻"
"腾鳆鸷吣归犸穑纨绪缧纤羡肤盖荞赵辎迁邬阁韬颗飞驽体鳃鹨黾仪刹撺晋秽纫义虫觞诎谊谢读赋踊辉选钧铪锪离鞴"
"馍驹髌鸳鼋龋乱妆携测纹统绱缵蓠赕辋郧银铘镏阀难韫髋咸俩侬咝娲怜摄检潴狱珉丝缦胶觯辍遗锄铠馒驵鸲鹾峡凭"
"擀樯殁浆泷狮痖眦笺纳绛绦絷胁苋荬蓝诅调谣锃钔驾鳄亿垫埝愦东濑玮缃缕缆芸荩蛏触质躯辽铳锔锴铩铴镧闺驺魇"
"鲈鸱硷仓哒颍皑缄圣脉萝赍钙锼闽题馐骚盐龌侩碜筝纽缂缥叶莸词谄账迈铜锇额馑骀骟鱼鲡个俭巯攒烂亩睑稳线赌"
"还钬镐钥阃陉颚馓驸哝抛挛桤绢腻荛蜗蚁咏谆辊钛铺锅阆颜馈鸪刚哕妫悦摊琼疯竞纾总诩狸辇钪镇镣镶闾饨馔驶亘"
"们剥昼疡碛纯缉绩询谟变迩镀陕饪鸶狍鼍墒卺惮奖稆箪纰缎闻胫诣谈跄酿镒铹饫驼鸯鹪毕讠趋辈边衅铖镦云颛骡鲧"
"鳋鸫亚傧嗳弪浑简纱缔订诿谪轮锆镡阅饬驷鲠鸭厍搅潋珑缗绷荭艺蛳讣试谬雠赖车邓酾锂镍镊阵饥蓦鹑哙崃张揽残"
"痪硖篑纸苟请猫轧铽饭饶骜鲥龙俦弃槟矶级绑缘缫莜蒉蝇轨逻酽铌镓镩骈骖侪喷强泼众纷缪虿见诗诤军逦铣锷钟电"
"愿骠鳏坠媪寝构璎画纭绡襁计谗跸辑铈镫阊颡饮飨骢庞妈抢枪殒畲砗缌诧诹让释铨锣驱鲩吨实愤洁琐箫讯诟赚郑锍"
"韵颠饴鳎鸸鹩剐宁甯柠争瑶瘗砚绠编荡药处规诡诼讴谰赙趱轩钶铡銮阉阴鲤鳐鸹审岗煅疮纺缓钵睃莲芜讧诠谅谶购"
"辏邻钆铃铢锯镢凿鲨龚伦凑异税绨苁蛱蝎贝赛轫郸钇阎陈类餍鹫丽龛写悯槛殇澜瓒疟胆蜕讨诘贞赜钌铭锻阏陆响骅"
"鹋剀厌宽炼疱秆缅脍荮萧薮觅话邺钴镨阍馋鳍鹇创咛怃潜莹硗禄联脱脓舱虚蛴讦该论负钊钹铫钢镎阈页偿苘爷玛当"
"聪苇虏蝾详谂谨财输郐钉铍阌顶颟骇骁鲁龟纬缯习声视谠贡钋钰衔顷饲厉问岽枨沣尔耸号蚝衮训诜阳巩饱馕骣鲢鹕"
"鹬弹宪枣殚滠皲绥缑织觇谳贽轭辐邝镞项颢饰鳌鹰厣吓峥炜琅缈缮聩脸蚬讪谀赘蹒针钸锞锎阒顺骆鳓鹗鹭堕姗宠柜"
"润皱扎聂讫谍谩踪铀铑锏顸顾鲂鲻鸿宝殓独瞩细练职脐蓣贫辗钿锸镄须鳘帅弥忆殡瘘粤绂经罂胀蚂记谝货赠软舆钾"
"录锲镟鲭狯祸绁缏聍膑舣荜诙贩铷链顼饺骄鱿鲞鲦麦划哜埯弯怅掴栋浈猃祯节绅缭兹荤亏裤贪赞锖镌闱颤鸽优札坟"
"妪闷晕歼签舰苈萤蜡裢讹贯毂钓铱锫颂颥饼验鲣师晖烟狞疗帘缇癯诖诨责迳钐铟锩锘镆阔陧麸椠畴睁范听蛎觋讶赡"
"轷辖钜镙镰阕队颀鲷鳗鸺剧哑败椁愍浔刘参启将叙杀溃洒刽噜专嵛栈寻帐彝壳伟刿掼涌储剑墙对茕啮导带搂毁滗垦"
"桊焕剂彦恳橹滩烦牍应桨殴俪怿揸栖汤帧懔涠炀涩澹傩帏灏傥坛俨榈汹栉丛浇呖妩敌畅椟涝湾凶挚橼滦咙数栎兑挟"
"桩于乐伙抠桉娴岚滟嵴儿垭压恶暂枞怼抟橱兖帼径掺槠菰唤垒帻栌涧喾圹懑敛桠沩牵严垆尴恼毙枥恽橥嘤榇彷藁届"
"帜恹坏从灾劲垄垅币恻栅娆尸徕捞渑吴楼侧内呐坜婵侦两娇栊泽荧丧啭娱准嗫标乔嚣执斓帮复惩泶炝勐伪吕单坝帱"
"撑榉荦冁屉挠晔沟伫懒扪枢毵哟壮怀樱浃呓屡悬昙浍动层捻样册坚嫱忏晓务屦淀干惧毡勋垩几挢壶彻慑斩温胜属恋"
"犊劳嘱栏氇寿爱掸杰呛嫒惬拨泾势啬丬牺垴嬷戆扫抡断权伧吗抚暧浊热后么嵝悫戋气浓伞朴愣备娄崭扑树氢埚嫔揿"
"桦椤氩吒沧坂幂岖旷灭呜囱栾氲挞为纟劢戗挣婴挝凼炽库戬挂捡榄涤溷淼来怆拥疴励唢杨荥烨状掳桡噘熘婶恺战憷"
"劝择晒湿凋佣匀尧够戏桥沉报偬净哔梦户击棂泞灯挡乌炖仑冻场凉传囵崂忾枫伛国书着债冈硅围厕担济伤厢沪噼厩"
"涛烧煳峤拣据会滞迭\0\0";
static char __szFF[TOTAL_CHAR_BUF]=
"嘆園汙獲籃繞聾藹褸諤轅這鉆銨鍬闌頏顯驚傾圓堿夾癆睞礎稟艫華藺訟貯贏轆釧銩階預顰餉驛鯝廈態滲疊癇築紹諦"
"貰贐連酈鉈銪頑顱養鰾鳥鶥鼴凜慍機燙獵矯窩紺綜繡肅薈褻誄諧證釩鉉銫鏑鐲頒嘍圖婦孌擠淒癉窪篋繢臘艱覦誅貲"
"轉銬鍰鐳闐頓顳餌鳧麯僂擡楨橢濫濫獷紼綞薊訣誆貳贓跡蹺隕顴駿驟鮁鯡團嶧燜獸現窮臚誇貴軫釬錐鐵霧鯢鳩鶩丟"
"滸睪窯綠艷荊薌訥諫鉍餑騁鮃侶僅濰獺紿親譎貶贖轍銱錒鏗闔際頗餒驢鯤嘔婭業淚濱營獻璉盜籌絀綢腎蘄誌諭譏買"
"贗轎鍵鏘鐸闕領餓鱅鸌咼奐欽獼綣蘆覬認諮貸銳鍶闖驤並嘖塊慘盞礙終繩臟蘇鉑錕鐺騅驥鯧僉嘗塋扡滾滾繪腖臠襆"
"訪貺長風鯨鱈鶯慚擬橫滿狹玀盡稭窶組縈蠱襇覯諱豈費贛軲進鏜頜鱉塏廚烴燦狽種縉翹蔔薔蘊螻誑貼銷錘鍺鏝餘鯪"
"鵑麼嘜孫極淥漁癘監絆縊繭翺萇蒓蘋設誒諳貽躉轔釵鉕錙鏞鐿鯫鵒齇凱塒廝揚擯盤筆縋罰臥蒔覲譖躊郟銹錚鏟關驪"
"鳳鵓匭慟換擰決稱窺繯蠶誕豎貿躋釷鉗錛餛鳴鶴俁匯廟擱橰淩濺盧禦糝綬繰罵臨萊諶識賀銻鍾鏡闞頡颮馬鮎鸕齊僑"
"嶴廠擲淪筍糞維芐許諷譙豐賁躍軸郤釹銼鏢隨颯馭騍鳶黃齋匱員塗廡慣濼燭甌癟碩罷腡誘諸譚賂軹鉚鑄門餞馮騎鮐"
"鯰哢廢擴桿禪綰縐繳蟄蠻裊覷賃躑軺鉛錟鏤闡險頤騏鮑嶸廣朧濾癡礦篤綱縑臯蔞訴誚諺譜賄躒軻錠鎂閂霽鮒鱒嘩奧"
"學歐癢絎網蒞薟賅躓軼閃頦餡馱鬢鸚齏嶺擷癤碭籜腦蟈覺訶諼躕鉞鋁錢鎄鞽鯴鱔鶻鸛齒奩慪淵甕癥禮篩結綴蔣蘗裏"
"資軾鏨闥馳鬥鵜鶼嘮奪嶼慫淶燴礪竄糧語諾賈轟鈀鋃鑊閆靂颶馴鱖鵝鸝黌齔嘯嶽廩擺癧瞇礫禰竅籟繹腫蔥覽遊鈁鎇"
"隱鬧鱗鸞嘰孿擻淺礬禱籠蔦蘚蟎襖診誠謀賊轡運鋅錦鑌靄韁騖鱘鶿塢廬慮揮擼沒瀅癩竇綸薦覿註誡謁躚轢郵閉隴鬩"
"鵠區嘵奮瀆璣碸竈絕綹繼觀謂較過鈄鉤鋇錨鎊韃頭館鮚鵡塤擾檁沖癬確綺繽羅腳臺薩誣轤達開騙鷂齙嘸癭竊篳綻縛"
"繾羆蘞誤謄踐輅違鉦閌隸靈颼慳漚瀉燼璦產癮碼礱筧蔭補誥謅錫頰骯鯽鱝俠猙癰綽縝羈裝詁誦躡輇遙鈈鋌鑒閎鬮鮞"
"齜慶瀋燾癱糲綾縞腸與芻襝賑鈉閏鯿鱟鴆點廳攄梔痙癲禿穌綿縟羋膁興蘢襠誨譫賒載遜錮鑔韉鴇僥僥別歟積籩糴耬"
"膃舉謊賓輊鋏錯閑齟僨協攆檉穎籪絝舊莊萬說躥遞鉬鏵韋鴉齠梘歡瀏瞘糶絞耮蝕術詆譯賕躦鈍鉭間韌駁鵪齡刪唄巋"
"漢環籬縣襤議遠醜鋒鏷閔雋頷飄餳黨漣秈緄纈謎豬鄆錳鎖頸鵬噅簀籮絡薺醞鈐鏹頹飆餵玨絢纊謐躪辦鈑鎘鱧條瀕發"
"緇蟣衛誰譴賚鄉閘頻飈餷鰈鵯齦塵宮琺瞞糾續蘭襪輒適雖鰉巒憂攏梟檔漬籲萵蒼蕁衝詎課賜鈔錸靚韓鮪渙瀘無紀給"
"緊莖謔謔護輔辭鈕靜鮫鵲黲巔損減緋縫纏蓀詐賞輕辮鑠雙鷓齪剄塹榪歲漲爍猶琿紂絨謖辯鉸餼騫鮭鰍鱭黴價巖攔時"
"況瀝縭苧蕆蝦襯詒誶謗賠農雛鮮鴕齬卻坰峴弒榮漵猻約縮蟬賡趕鉺鋝鑣雜餾騭倀則攖瀟爐璽簍紅纓詔謙賢遲醫鉻鐃"
"靦韙餿騮髏鷗黷噓島恥搖檜渦漸瀠磚紆羥蟯襲評誹謚譽賣鄒醬鋟鍀鎢鑥閡雞魎鹵憊搗攙歷紇縱莢講譾賤輛鍁鎣靨駐"
"騰鰒鷙唚歸獁穡紈緒縲纖羨膚蓋蕎趙輜遷鄔閣韜顆飛駑體鰓鷚黽儀剎攛晉穢紉義蟲觴詘誼謝讀賦踴輝選鈞鉿鍃離韝"
"饃駒髕鴛黿齲亂妝攜測紋統緔纘蘺賧輞鄖銀鋣鎦閥難韞髖鹹倆儂噝媧憐攝檢瀦獄瑉絲縵膠觶輟遺鋤鎧饅駔鴝鹺峽憑"
"搟檣歿漿瀧獅瘂眥箋納絳絳縶脅莧蕒藍詛調謠鋥鍆駕鱷億墊墊憒東瀨瑋緗縷纜蕓藎蟶觸質軀遼銃鋦鍇鎩鐋鑭閨騶魘"
"鱸鴟鹼倉噠潁皚緘聖脈蘿賫鈣鎪閩題饈騷鹽齷儈磣箏紐緙縹葉蕕詞諂賬邁銅鋨額饉駘騸魚鱺個儉巰攢爛畝瞼穩線賭"
"還鈥鎬鑰閫陘顎饊駙噥拋攣榿絹膩蕘蝸蟻詠諄輥鈦鋪鍋閬顏饋鴣剛噦媯悅攤瓊瘋競紓總詡貍輦鈧鎮鐐鑲閭飩饌駛亙"
"們剝晝瘍磧純緝績詢謨變邇鍍陜飪鷥麅鼉墑巹憚獎穭簞紕緞聞脛詣談蹌釀鎰鐒飫駝鴦鷦畢訁趨輩邊釁鋮鐓雲顓騾鯀"
"鰠鶇亞儐噯弳渾簡紗締訂諉謫輪鋯鐔閱飭駟鯁鴨厙攪瀲瓏緡繃葒藝螄訃試謬讎賴車鄧釃鋰鎳鑷陣饑驀鶉噲崍張攬殘"
"瘓硤簣紙茍請貓軋鋱飯饒驁鰣龍儔棄檳磯級綁緣繅蓧蕢蠅軌邏釅鈮鎵鑹駢驂儕噴強潑眾紛繆蠆見詩諍軍邐銑鍔鐘電"
"願驃鰥墜媼寢構瓔畫紜綃繈計讒蹕輯鈰鐙閶顙飲饗驄龐媽搶槍殞畬硨緦詫諏讓釋銓鑼驅鯇噸實憤潔瑣簫訊詬賺鄭鋶"
"韻顛飴鰨鴯鷯剮寧寧檸爭瑤瘞硯綆編蕩藥處規詭諑謳讕賻趲軒鈳鍘鑾閹陰鯉鰩鴰審崗煆瘡紡緩缽脧蓮蕪訌詮諒讖購"
"輳鄰釓鈴銖鋸鐝鑿鯊龔倫湊異稅綈蓯蛺蠍貝賽軔鄲釔閻陳類饜鷲麗龕寫憫檻殤瀾瓚瘧膽蛻討詰貞賾釕銘鍛閼陸響驊"
"鶓剴厭寬煉皰稈緬膾葤蕭藪覓話鄴鈷鐠閽饞鰭鷴創嚀憮潛瑩磽祿聯脫膿艙虛蠐訐該論負釗鈸銚鋼鎿閾頁償檾爺瑪當"
"聰葦虜蠑詳諗謹財輸鄶釘鈹閿頂顢駭驍魯龜緯繒習聲視讜貢釙鈺銜頃飼厲問崠棖灃爾聳號蠔袞訓詵陽鞏飽饢驏鰱鶘"
"鷸彈憲棗殫灄皸綏緱織覘讞贄軛輻鄺鏃項顥飾鰲鷹厴嚇崢煒瑯緲繕聵臉蜆訕諛贅蹣針鈽錁鐦闃順駱鰳鶚鷺墮姍寵櫃"
"潤皺紮聶訖諜謾蹤鈾銠鐧頇顧魴鯔鴻寶殮獨矚細練職臍蕷貧輾鈿鍤鐨須鰵帥彌憶殯瘺粵紱經罌脹螞記諞貨贈軟輿鉀"
"錄鍥鏇鯖獪禍紲緶聹臏艤蓽詼販銣鏈頊餃驕魷鯗鰷麥劃嚌垵彎悵摑棟湞獫禎節紳繚茲葷虧褲貪贊錆鐫闈顫鴿優劄墳"
"嫗悶暈殲簽艦藶螢蠟褳訛貫轂釣銥錇頌顬餅驗鰹師暉煙獰療簾緹臒詿諢責逕釤銦錈鍩鏌闊隉麩槧疇睜範聽蠣覡訝贍"
"軤轄鉅鏍鐮闋隊頎鯛鰻鵂劇啞敗槨湣潯劉參啟將敘殺潰灑劊嚕專崳棧尋帳彜殼偉劌摜湧儲劍墻對煢嚙導帶摟毀潷墾"
"棬煥劑彥懇櫓灘煩牘應槳毆儷懌摣棲湯幀懍潿煬澀淡儺幃灝儻壇儼櫚洶櫛叢澆嚦嫵敵暢櫝澇灣兇摯櫞灤嚨數櫟兌挾"
"樁於樂夥摳案嫻嵐灩脊兒埡壓惡暫樅懟摶櫥兗幗徑摻櫧菇喚壘幘櫨澗嚳壙懣斂椏溈牽嚴壚尷惱斃櫪惲櫫嚶櫬仿槁屆"
"幟懨壞從災勁壟壟幣惻柵嬈屍徠撈澠吳樓側內吶壢嬋偵兩嬌櫳澤熒喪囀娛準囁標喬囂執斕幫復懲澩熗猛偽呂單壩幬"
"撐櫸犖囅屜撓曄溝佇懶捫樞毿喲壯懷櫻浹囈屢懸曇澮動層撚樣冊堅嬙懺曉務屨澱幹懼氈勛堊幾撟壺徹懾斬溫勝屬戀"
"犢勞囑欄氌壽愛撣傑嗆嬡愜撥涇勢嗇爿犧堖嬤戇掃掄斷權傖嗎撫曖濁熱後麽嶁愨戔氣濃傘樸楞備婁嶄撲樹氫堝嬪撳"
"樺欏氬咤滄阪冪嶇曠滅嗚囪欒氳撻為糸勱戧掙嬰撾氹熾庫戩掛撿欖滌混渺來愴擁屙勵嗩楊滎燁狀擄橈撅溜嬸愷戰怵"
"勸擇曬濕雕傭勻堯夠戲橋沈報傯凈嗶夢戶擊欞濘燈擋烏燉侖凍場涼傳圇嶗愾楓傴國書著債岡矽圍廁擔濟傷廂滬劈廄"
"濤燒糊嶠揀據會滯叠\0\0";

static void code_to_file(const char *filename, const char *name_pre,
	const char *from_tab, const char *to_tab)
{
	char  buf[255];
	ACL_FILE *fp;
	int   i;
	unsigned short table[65535];

	// 初始化
	for (i = 0; i < 65535; i++) {
		table[i] = 0xffff;
	}
	unsigned short *ptr1 = (unsigned short*) from_tab;
	unsigned short *ptr2 = (unsigned short*) to_tab;
	while (*ptr1 != 0) {
		table[*ptr1] = *ptr2;
		if (*ptr2 == 0xa1b3) {
			printf(">>>>>ptr2: 0x%x, %d, ptr1: %d, 0x%x\n", *ptr2, *ptr2, *ptr1, *ptr1);
		}
		*ptr1++;
		*ptr2++;
	}

	printf(">>>>>table[41395]: 0x%x\n", table[41395]);

	fp = acl_fopen(filename, "w+");
	snprintf(buf, sizeof(buf), "static unsigned short %s[] = {\n", name_pre);
	acl_fwrite(buf, strlen(buf), 1, fp);
	for (i = 0; i < 65535; i++) {
		if (i % 8 == 0) {
			if (i == 0)
				snprintf(buf, sizeof(buf), "\t");
			else
				snprintf(buf, sizeof(buf), "\n\t");
			acl_fwrite(buf, strlen(buf), 1, fp);
		}
		snprintf(buf, sizeof(buf), "0x%x,", table[i]);
		acl_fwrite(buf, strlen(buf), 1, fp);
	}
	snprintf(buf, sizeof(buf), "\n};\n");
	acl_fwrite(buf, strlen(buf), 1, fp);
	acl_fclose(fp);
}

static void code_map(const char *filename, const char *data)
{
	ACL_FILE *fp = acl_fopen(filename, "w+");
	unsigned short *ptr = (unsigned short*) data;
	char  buf[16];

	acl_fputs("static unsigned short __map_tab[] = {", fp);
	while (*ptr != 0) {
		snprintf(buf, sizeof(buf), "0x%x,", *ptr);
		acl_fwrite(buf, strlen(buf), 1, fp);
		ptr++;
	}
	acl_fputs("\n};", fp);
	acl_fclose(fp);
}

static void write_code(void)
{
	printf("jt2ft\n");
	code_to_file("jt2ft.h", "__jt2ft_tab", __szJJ, __szJF);
	printf("ft2jt\n");
	code_to_file("ft2jt.h", "__ft2jt_tab", __szFF, __szFJ);
	getchar();

	return;
	//场础贰尽馈谩拧伞
	code_map("j2f.txt", "场础贰尽馈谩拧伞\0\0");
	char  buf[256];
	unsigned short a[] = {0xf688,0x3666,0x3636,0x2c,0x81f0,0x99d6,0x5194,0xe382, 0};
	unsigned short *p = (unsigned short*) buf, i;

	memset(buf, 0, sizeof(buf));

	for (i = 0; a[i]; i++) {
		*p++ = a[i];
	}

	printf(">>%S\n", buf);
	getchar();
}

int main(int argc, char *argv[])
{
	write_code();
	return (0);
}
